pub fn parse_order_book_snapshot(
snapshot: &LighterOrderBookOrders,
instrument_id: InstrumentId,
price_precision: u8,
size_precision: u8,
ts_event: UnixNanos,
ts_init: UnixNanos,
) -> Result<OrderBookDeltas>Expand description
Parses an HTTP order book snapshot response into Nautilus order book deltas.
Errors
Returns an error if any price or size cannot be converted.